{% with webpage_name="privacy policy" webpage_url="admin:core_website_app_privacy" %}
    {% if DISPLAY_NIST_HEADERS %}
        {% include 'core_main_app/admin/web_page/web_page_unavailable.html' %}
    {% else %}
        {% include 'core_main_app/admin/web_page/web_page.html' %}
    {% endif %}
{% endwith %}