""" Type of WebPages
"""
from core_main_app.commons.enums import WEB_PAGE_TYPES

WEB_PAGE_TYPES.update(
    {
        "terms_of_use": 0,
        "privacy_policy": 1,
        "help": 2,
        "rules_of_behavior": 4,
    }
)
