{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}

{% block modal_id %}delete-message-modal{% endblock %}
{% block modal_title %}Delete message{% endblock %}

{% block modal_body %}
    Are you sure you want to delete this message?
    <input type="hidden" id="delete-message-id" value=""/>
{% endblock %}

{% block modal_footer %}
<button class="btn btn-secondary pull-left" data-dismiss="modal"><i class="fa fa-times"></i> Cancel</button>
<button id="btn-delete-message" class="btn btn-danger"><i class="fa fa-trash"></i> Confirm</button>
{% endblock %}