Dear {{firstname}} {{lastname}},

<br/>

Unfortunately, your account request on {{URI}} has been denied.
<br/>
For more information on your account request, please  <a href="{{URI}}{% url 'core_website_app_contact' %}">contact</a> the administrator.

<br/>

Thank you,
<br/>