<div id="dialog-deleted-message" title="Message Deleted" style="display:none;">
  <p>
  <span class="ui-icon ui-icon-circle-check" style="float:left; margin:0 7px 10px 0;"></span>
  Message deleted with success.
  </p>
</div>