/**
 * 
 * File Name: user_account_req.js
 * Author: Sharief Youssef
 * 		   sharief.youssef@nist.gov
 *
 *        Guillaume SOUSA AMARAL
 *        guillaume.sousa@nist.gov
 * 
 * Sponsor: National Institute of Standards and Technology (NIST)
 * 
 */

/**
 * Return to profile
 */
returnProfile = function()
{
	window.location = '/dashboard/my-profile';
}