<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Account Requested</title>
</head>
<body>
Dear Administrator,
<br><br>

A new account on {{URI}} has been requested.<br>
Please login to the application to accept or deny the account request: <a href="{{URI}}{% url 'admin:core_website_app_user_requests' %}">Go to the request</a>.

<br><br>

Thank you,
<br><br>
</body>
</html>