<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Requested Account</title>
</head>
<body>
Dear {{firstname}} {{lastname}} ,
<br><br>

Your request for a new account on {{URI}} has been submitted.<br>
You will receive an email once your account is created.

<br><br>

Thank you,
<br><br>
</body>
</html>