{% extends 'core_main_app/_render/admin/theme/tools/box.html' %}

{% block box_title %}Pending messages{% endblock %}

{% block box_body %}
<table class="table table-bordered table-striped table-hover">
    <tr>
        <th>Name</th>
        <th>Email Address</th>
        <th>Message</th>
        <th>Actions</th>
    </tr>

    {% for message in data.contacts %}
        <tr id="{{ message.id }}">
            <td width="10%">{{ message.name }}</td>
            <td width="10%">{{ message.email }}</td>
            <td width="70%" class="message word-wrap">{{ message.content }}</td>
            <td>
                <div class="btn btn-danger remove_message">
                    <i class="fa fa-trash"></i> Delete
                </div>
            </td>
        </tr>
    {% empty %}
        <tr class="empty">
            <td colspan="4">No messages received.</td>
        </tr>
    {% endfor %}
</table>
{% endblock %}