<div id="dialog-accepted-request" title="Request Accepted" style="display:none;">  
  <p>
  <span class="ui-icon ui-icon-circle-check" style="float:left; margin:0 7px 10px 0;"></span>
  User created with success.
  </p>
</div>