""" App bundling basic functionalities for a minimal working website. Included in this app are the following:
    * Account requests: Request a new account to the administrator
    * Contact messages: Send private messages to the administrator
    * Help, Privacy policy and Terms of use: Special pages for the website

Authors:
    * Adrien Catel (adrien.catel@nist.gov)
    * Philippe Dessauw (philippe.dessauw@nist.gov)
    * Guillaume Sousa (guillaume.sousa@nist.gov)
    * Sharief Youssef (sharief.youssef@nist.gov)

Sponsor:
    Alden Dima (alden.dima@nist.gov)

    | Information Systems Group
    | Software and Systems Division
    | Information Technology Laboratory
    | National Institute of Standards and Technology
    | http://www.nist.gov/itl/ssd/is
"""
