{% load staticfiles %}
{% load stripjs %}
<div class="row">
    <div class="col-md-12">
		<h2>Help</h2>

		<div class="left word-wrap">
			{% if data.help %}
				{{ data.help.content | stripjs }}
			{% else %}
				<div class="left large">
					<p>
					  <a href="#What-is-the-Curation-System">What is the {{CUSTOM_NAME}}?</a><br/>
					  <a href="#How-do-I-get-access">How do I get access to the {{CUSTOM_NAME}}?</a><br/>
					  <a href="#What-are-activities">What are some of the activities I can do on the {{CUSTOM_NAME}}?</a><br/>
					  <a href="#Can-I-use-RESTful-API">Can I use {{CUSTOM_NAME}} using a RESTful API?</a><br/>
                      <a href="#How-can-I-get-help">How do I get help with questions?</a><br/>
					  <a href="#How-do-I-contact-the-admin">How do I contact the {{CUSTOM_NAME}} administrator for questions?</a><br/>
					</p>
				</div>
				<div class="clearer">&nbsp;</div>
				<hr/>
				<br/>

				<h3 id="What-is-the-Curation-System">What is the {{CUSTOM_NAME}}?</h3>
				<p class="large">
					The {{CUSTOM_NAME}} allows for the curation of materials data into a repository using predefined templates. The system also allows
					for browsing and exploring of the materials data using the predefined templates as well.
				</p>

				<div class="clearer">&nbsp;</div>

				<h3 id="How-do-I-get-access">How do I get access to the {{CUSTOM_NAME}}?</h3>
				<p class="large">
					An individual may make a request to access {{CUSTOM_NAME}} using the online request form. Once the {{CUSTOM_NAME}} administrator accepts
					the account request, the user is notified that the account is created with the appropriate credentials.
				</p>

				<div class="clearer">&nbsp;</div>

				<h3 id="What-are-activities">What are some of the activities I can do on the {{CUSTOM_NAME}}?</h3>
				<p class="large">
					A user can enter and curate materials data, search and explore materials data, and perform a federation of queries
					across several {{CUSTOM_NAME}} instances.
				</p>

				<div class="clearer">&nbsp;</div>

				<h3 id="Can-I-use-RESTful-API">Can I use {{CUSTOM_NAME}} using a RESTful API?</h3>
				<p class="large">
					Yes, {{CUSTOM_NAME}} supports RESTful APIs. The {{CUSTOM_NAME}} REST-based APIs allow the integration with other Web services, data entry,
					query, and retrieval. The RESTful API documentation can be accessed <a href="{% url 'swagger_view'%}">here</a>.
				</p>

				<div class="clearer">&nbsp;</div>

                <h3 id="How-can-I-get-help">How do I get help with questions?</h3>
                <p class="large">
                    A Google Group has been established for discussion/questions about the CDCS systems developed by NIST. A Google account is required for posting.
                     <br>
                    Site: <a href="https://groups.google.com/d/forum/mdcs-mgi">https://groups.google.com/d/forum/mdcs-mgi</a>
                     <br>
                    Email: <a href="mailto:mdcs-mgi@googlegroups.com">mdcs-mgi@googlegroups.com</a>
                </p>

                <div class="clearer">&nbsp;</div>

				<h3 id="How-do-I-contact-the-admin">How do I contact the {{CUSTOM_NAME}} administrator for questions?</h3>
				<p class="large">
					You can contact the {{CUSTOM_NAME}} administrator using this
                    <a href="{% url 'core_website_app_contact' %}">form</a>.
				</p>
			{% endif %}
		</div>
	</div>
</div>
